colour.appearance — Colour 0.3.0 documentation

# Source code for colour.appearance

    #!/usr/bin/env python
    # -*- coding: utf-8 -*-

    from __future__ import absolute_import

    from .hunt import (
        Hunt_InductionFactors,
        HUNT_VIEWING_CONDITIONS,
        Hunt_Specification,
        XYZ_to_Hunt)
    from .atd95 import ATD95_Specification, XYZ_to_ATD95
    from .ciecam02 import (
        CIECAM02_InductionFactors,
        CIECAM02_VIEWING_CONDITIONS,
        CIECAM02_Specification,
        XYZ_to_CIECAM02,
        CIECAM02_to_XYZ)
    from .llab import (
        LLAB_InductionFactors,
        LLAB_VIEWING_CONDITIONS,
        LLAB_Specification,
        XYZ_to_LLAB)
    from .nayatani95 import Nayatani95_Specification, XYZ_to_Nayatani95
    from .rlab import (
        RLAB_VIEWING_CONDITIONS,
        RLAB_D_FACTOR,
        RLAB_Specification,
        XYZ_to_RLAB)

    __all__ = ['Hunt_InductionFactors',
               'HUNT_VIEWING_CONDITIONS',
               'Hunt_Specification',
               'XYZ_to_Hunt']
    __all__ += ['ATD95_Specification', 'XYZ_to_ATD95']
    __all__ += ['CIECAM02_InductionFactors',
                'CIECAM02_VIEWING_CONDITIONS',
                'CIECAM02_Specification',
                'XYZ_to_CIECAM02',
                'CIECAM02_to_XYZ']
    __all__ += ['LLAB_VIEWING_CONDITIONS', 'LLAB_Specification', 'XYZ_to_LLAB']
    __all__ += ['Nayatani95_Specification', 'XYZ_to_Nayatani95']
    __all__ += ['RLAB_VIEWING_CONDITIONS',
                'RLAB_D_FACTOR',
                'RLAB_Specification',
                'XYZ_to_RLAB']